package application.world;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import javafx.scene.image.Image;

/**
 * Represents one World Item that can be placed within the World Grid to given [x,y] coordinates.
 * It is graphically presented by the Image passed by img parameter to the constructor and it can 
 * contain string value, that can be passed to the Actor when enters the World Grid cell with this World Item.
 * 
 * Note: Actually the prototype is designed that image has 38x38 pixels. In next version of the application, the GUI - World Grid should be enhanced, so it's
 * size is scalable.
 * 
 * @author Pavel Bory
 *
 */
public class WorldItem {
	private static final Logger logger = LogManager.getLogger(WorldItem.class);
	
	private long positionX;
	private long positionY;
	private String value;
	private Image img;
	
	public WorldItem(long positionX, long positionY, String value, Image img) {
		super();
		this.positionX = positionX;
		this.positionY = positionY;
		this.value = value;
		this.img = img;
		logger.trace("Creating World Item, x: {}, y: {}, value: {}",positionX,positionY,value);
	}

	public long getPositionX() {
		return positionX;
	}

	public void setPositionX(long positionX) {
		this.positionX = positionX;
	}

	public long getPositionY() {
		return positionY;
	}

	public void setPositionY(long positionY) {
		this.positionY = positionY;
	}

	public String getValue() {
		return value;
	}

	public void setValue(String value) {
		this.value = value;
	}

	public Image getImg() {
		return img;
	}

	public void setImg(Image img) {
		this.img = img;
	}
}
