package application.world.ruby;

import java.util.Arrays;
import java.util.HashMap;

import org.jruby.RubyException;
import org.jruby.embed.ScriptingContainer;

import application.world.Actor;
import application.world.WorldActorUnsupportedOperationException;

public class JRubyContainer {
	private static final String JRubyStdLibPath = "C:\\jruby-9.1.6.0\\lib\\ruby\\stdlib";
	
	private IRubyActor actor;
	private ScriptingContainer container;
	
	public JRubyContainer(){
		container = new ScriptingContainer();
		container.setLoadPaths(Arrays.asList("libs",JRubyStdLibPath));
		container.runScriptlet("require 'actor.rb'");
	}
	
	public void loadCodeForActor(Actor currentJavaActorState,String code){
		actor = (IRubyActor) container.runScriptlet("Actor.instance");
		actor.setPositionX(currentJavaActorState.getPositionX());
		actor.setPositionY(currentJavaActorState.getPositionY());
		actor.loadActorActionMethod(code);
	}
	
	public RubyActorActionType makeActorAction(Actor currentJavaActorState, String input) throws WorldActorUnsupportedOperationException {
		actor.setPositionX(currentJavaActorState.getPositionX());
		actor.setPositionY(currentJavaActorState.getPositionY());
		actor.setInput(input);
		try{
			return actor.makeAction();
		}catch(Exception e){
			throw new WorldActorUnsupportedOperationException("The Actor action caused exception. Check if the return value is one of the allowed actions.");
		}
	}
	
	public HashMap<String, Object> getActorData(){
		if(actor != null){
			return actor.getData();
		}
		return new HashMap<String,Object>();
	}
	
	public String gatherOutputText(){
		if(actor != null){
			return actor.gatherOutputText();
		}
		return null;
	}
}
