package application.worldgraphics;

import application.world.World;
import application.world.WorldItem;
import javafx.scene.canvas.Canvas;
import javafx.scene.canvas.GraphicsContext;
import javafx.scene.image.Image;
import javafx.scene.paint.Color;

public class WorldGrid {	
	private final int cellWidth;
	private final int cellHeight;
	
	private Canvas canvas;
	
	public WorldGrid(Canvas canvas){
		this.canvas = canvas;
		cellWidth = ((Double)canvas.getWidth()).intValue() / World.WORLD_COLUMNS_COUNT;
		cellHeight = ((Double)canvas.getHeight()).intValue() / World.WORLD_ROWS_COUNT;
	}
	
	public void drawGrid(Color[][] gridCellColors){
		 GraphicsContext gc = canvas.getGraphicsContext2D(); 
		 gc.clearRect(0, 0, canvas.getWidth(), canvas.getHeight());
		 
		 gc.setStroke(Color.BLACK);   
		 // vertical lines 
	     for(int i = 0 ; i <= World.WORLD_COLUMNS_COUNT ; i++){
	    	 int x = i * cellWidth;
	    	 gc.strokeLine(x, 0, x, canvas.getHeight());
	     }        

	     // horizontal lines
	     for(int i = 0 ; i <= World.WORLD_ROWS_COUNT ; i++){
	    	 int y = i * cellHeight;
	    	 gc.strokeLine(0, y, canvas.getWidth(), y);
	     }        
	     
	     if(gridCellColors != null){
	    	 for(int col = 0; col < World.WORLD_COLUMNS_COUNT; col++){
	    		 for(int row = 0; row < World.WORLD_ROWS_COUNT; row++){
	    			 if(gridCellColors[col][row] != null){
	    				 gc.setFill(gridCellColors[col][row]);
	    				 gc.fillRect(col * cellWidth + 1, row * cellHeight + 1, 38, 38);
	    			 }
	    		 }
	    	 }
	     }
	}
	
	public void drawActor(long x, long y,Image actorImg){
	    GraphicsContext gc = canvas.getGraphicsContext2D();
	    gc.drawImage(actorImg, x * cellWidth + 1, y * cellHeight + 1);
	}
	
	public void drawItems(WorldItem[][] items){
	    GraphicsContext gc = canvas.getGraphicsContext2D();
	    if(items != null){
	    	 for(int col = 0; col < World.WORLD_COLUMNS_COUNT; col++){
	    		 for(int row = 0; row < World.WORLD_ROWS_COUNT; row++){
	    			 if(items[col][row] != null){
	    				 gc.drawImage(items[col][row].getImg(), col * cellWidth + 1, row * cellHeight + 1);
	    			 }
	    		 }
	    	 }
	     }
	}
}
